summaryrefslogtreecommitdiff
path: root/src/localplayer.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/localplayer.h')
-rw-r--r--src/localplayer.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/localplayer.h b/src/localplayer.h
index ce181c74..c94dba74 100644
--- a/src/localplayer.h
+++ b/src/localplayer.h
@@ -143,11 +143,11 @@ class LocalPlayer : public Player
* displayed as soon as the player attacks, not when the server says
* the player does.
*
* @param victim The attacked being.
* @param damage The amount of damage dealt (0 means miss).
*/
- virtual void handleAttack(Being *victim, int damage) {}
-
+ virtual void handleAttack(Being *victim, int damage, AttackType type) {}
/**
* Returns the current target of the player. Returns 0 if no being is
* currently targeted.
@@ -143,11 +143,11 @@ class LocalPlayer : public Player
* the player does.
*
- * @param victim The attacked being.
- * @param damage The amount of damage dealt (0 means miss).
+ * @param victim the victim being
+ * @param damage the amount of damage dealt (0 means miss)
+ * @param type the attack type
*/